@@ -19,6 +19,33 @@ haploGen <- function(seq.length=10000, mu=0.0001, t.max=20,
     if(!require(ape)) stop("The ape package is required.")
 
 
+    ## HACK TO FIX APE'S BUG ##
+    env <- environment(as.list.DNAbin)
+    as.list.DNAbin.new <- function (x, ...){
+        if (is.list(x))
+            return(x)
+        if (is.null(dim(x)))
+            obj <- list(x)
+        else {
+            n <- nrow(x)
+            obj <- vector("list", n)
+            for (i in 1:n) obj[[i]] <- x[i, ]
+            names(obj) <- rownames(x)
+        }
+        class(obj) <- "DNAbin"
+        obj
+    }
+
+    as.list.DNAbin <- as.list.DNAbin.new
+    unlockBinding("as.list.DNAbin", env)
+    assignInNamespace("as.list.DNAbin", as.list.DNAbin.new, ns="ape", envir=env)
+    assign("as.list.DNAbin", as.list.DNAbin.new, envir=env)
+    lockBinding("as.list.DNAbin", env)
+
+    ## END HACK ##
+
+
+
     ## HANDLE ARGUMENTS ##
     if(is.numeric(mu)){
         mu.val <- mu
@@ -47,14 +74,15 @@ haploGen <- function(seq.length=10000, mu=0.0001, t.max=20,
     ## AUXILIARY FUNCTIONS ##
     ## generate sequence from scratch
     seq.gen <- function(){
-        res <- list(sample(NUCL, size=seq.length, replace=TRUE))
+        ##res <- list(sample(NUCL, size=seq.length, replace=TRUE)) # DNAbin are no longer lists by default
+        res <- sample(NUCL, size=seq.length, replace=TRUE)
         class(res) <- "DNAbin"
         return(res)
     }
 
     ## create substitutions for defined SNPs
     substi <- function(snp){
-        res <- sapply(snp, function(e) sample(setdiff(NUCL,e),1))
+        res <- sapply(1:length(snp), function(e) sample(setdiff(NUCL,e),1)) # ! sapply does not work on DNAbin vectors directly
         class(res) <- "DNAbin"
         return(res)
     }
